@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0700';
+our $VERSION = '0.0701';
 
 use Moo;
 use strictures 2;
@@ -199,7 +199,7 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0700
+version 0.0701
 
 =head1 SYNOPSIS
 
@@ -340,10 +340,16 @@ Run the asynchronous B<loop>!
 
 =head2 open_controllers
 
-  $controllers = $control->open_controllers($inputs, $output);
+  $controllers = MIDI::RtController::open_controllers(
+    $input_names, $output_name, $verbose
+  );
 
 Return a hash reference of C<MIDI::RtController> instances, keyed by
-a comma-separated string of MIDI input controller device names.
+each input (given by a comma-separated string of MIDI B<input_names>
+controller devices).
+
+The B<output_name> is used for the MIDI output device for each
+instance. The B<verbose> Boolean flag is passed to the instances.
 
 =head1 THANK YOU
 
